==> paper-api-1.20.6-R0.1-20241030.191541-127-sources.jar: io/papermc/paper/scoreboard/numbers/NumberFormat.java <==
package io.papermc.paper.scoreboard.numbers;

import net.kyori.adventure.text.ComponentLike;
import net.kyori.adventure.text.format.Style;
import net.kyori.adventure.text.format.StyleBuilderApplicable;
import org.jetbrains.annotations.NotNull;

/**
 * Describes a scoreboard number format that applies custom formatting to scoreboard scores.
 */
public interface NumberFormat {

    /**
     * Creates a blank scoreboard number format that removes the score number entirely.
     *
     * @return a blank number format
     */
    static @NotNull NumberFormat blank() {
        return BlankFormatImpl.INSTANCE;
    }

    /**
     * Gets an un-styled number format.
     *
     * @return an un-styled number format
     */
    static @NotNull StyledFormat noStyle() {
        return StyledFormatImpl.NO_STYLE;
    }

    /**
     * Creates a scoreboard number format that applies a custom formatting to the score number.
     *
     * @param style the style to apply on the number
     * @return a styled number format
     */
    static @NotNull StyledFormat styled(final @NotNull Style style) {
        return new StyledFormatImpl(style);
    }

    /**
     * Creates a scoreboard number format that applies a custom formatting to the score number.
     *
     * @param styleBuilderApplicables the style to apply on the number
     * @return a styled number format
     */
    static @NotNull StyledFormat styled(final @NotNull StyleBuilderApplicable @NotNull... styleBuilderApplicables) {
        return styled(Style.style(styleBuilderApplicables));
    }

    /**
     * Creates a scoreboard number format that replaces the score number with a chat component.
     *
     * @param component the component to replace the number with
     * @return a fixed number format
     */
    static @NotNull FixedFormat fixed(final @NotNull ComponentLike component) {
        return new FixedFormatImpl(component.asComponent());
    }
}

==> paper-api-1.21.6-R0.1-20250630.094942-50-sources.jar: io/papermc/paper/scoreboard/numbers/NumberFormat.java <==
package io.papermc.paper.scoreboard.numbers;

import net.kyori.adventure.text.ComponentLike;
import net.kyori.adventure.text.format.Style;
import net.kyori.adventure.text.format.StyleBuilderApplicable;
import org.jspecify.annotations.NullMarked;

/**
 * Describes a scoreboard number format that applies custom formatting to scoreboard scores.
 */
@NullMarked
public interface NumberFormat {

    /**
     * Creates a blank scoreboard number format that removes the score number entirely.
     *
     * @return a blank number format
     */
    static NumberFormat blank() {
        return BlankFormatImpl.INSTANCE;
    }

    /**
     * Gets an un-styled number format.
     *
     * @return an un-styled number format
     */
    static StyledFormat noStyle() {
        return StyledFormatImpl.NO_STYLE;
    }

    /**
     * Creates a scoreboard number format that applies a custom formatting to the score number.
     *
     * @param style the style to apply on the number
     * @return a styled number format
     */
    static StyledFormat styled(final Style style) {
        return new StyledFormatImpl(style);
    }

    /**
     * Creates a scoreboard number format that applies a custom formatting to the score number.
     *
     * @param styleBuilderApplicables the style to apply on the number
     * @return a styled number format
     */
    static StyledFormat styled(final StyleBuilderApplicable... styleBuilderApplicables) {
        return styled(Style.style(styleBuilderApplicables));
    }

    /**
     * Creates a scoreboard number format that replaces the score number with a chat component.
     *
     * @param component the component to replace the number with
     * @return a fixed number format
     */
    static FixedFormat fixed(final ComponentLike component) {
        return new FixedFormatImpl(component.asComponent());
    }
}
